@@ -102,8 +102,8 @@ typedef unsigned long guintptr;
 #endif
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 54
-#define GLIB_MICRO_VERSION 2
+#define GLIB_MINOR_VERSION 56
+#define GLIB_MICRO_VERSION 1
 
 #define G_OS_UNIX
 
@@ -192,6 +192,11 @@ typedef int GPid;
 #define GLIB_SYSDEF_MSG_PEEK 2
 #define GLIB_SYSDEF_MSG_DONTROUTE 4
 
+#define G_DIR_SEPARATOR '/'
+#define G_DIR_SEPARATOR_S "/"
+#define G_SEARCHPATH_SEPARATOR ':'
+#define G_SEARCHPATH_SEPARATOR_S ":"
+
 G_END_DECLS
 
 #endif /* __GLIBCONFIG_H__ */
